@@ -1,6 +1,6 @@
 (defun jamie-load-clcs (&optional (mode :compiled))
   (let ((files (list 
-		"package"
+		;"package"
 		"precom"
 		"macros"
 		"restart"
@@ -11,6 +11,7 @@
 		"kcl-cond"
 		"top-patches"
 		"install")))
+     (load "package.lisp")
     (when (eql :compile mode)
 	  (load "package.lisp")
 	  (load "precom.lisp"))
@@ -21,3 +22,5 @@
 		     (:compile (compile-file (format nil "~A.lisp" file)))))
 	  files)))
 
+
+
