@@ -7,7 +7,7 @@
 object make_integer();
   /* copy x to y, increasing space by factor of 2  */
 
-
+#ifndef GMP
 GEN otoi();
 /*
 object integ_temp;
@@ -33,5 +33,7 @@ GEN setq_io(),setq_ii();
 #define IDECL(a,b,c) our_ulong b[4];a =(b[0]=0x1010000 +4,b);object c
 #endif
 
+#endif /* end no GMP */
+
 #define	cclosure_call	funcall
 
