@@ -1,27 +1,42 @@
 /* if already mp.h has been included skip */
-typedef  long *GEN1;
+#ifdef _MP_H
+#ifdef GMP
+
+#else /* no gmp */
+
+typedef  plong *GEN1;
 /* if genpari.h not loaded */
 #ifndef MAXBLOC
-typedef  long *GEN;
+typedef  plong *GEN;
 GEN1 addii(),mulii(),mulsi(),powerii(),shifti(),stoi(),dvmdii(),subii();
 int cmpii();
-long itos();
+plong itos();
 #define signe(x)          (((GEN1)(x))[1]>>24)
 #define lg(x)             (((GEN1)(x))[0]&0xffff)
 #define setlg(x,s)        (((GEN1)(x))[0]=(((GEN1)(x))[0]&0xffff0000)+s)
 #define lgef(x)           (((GEN1)(x))[1]&0xffff)
 #define setlgef(x,s)      (((GEN1)(x))[1]=(((GEN1)(x))[1]&0xffff0000)+s)
 
-#define our_ulong unsigned long
+#define our_ulong unsigned plong
 #endif /* end MAXBLOC */
 
 
 EXTER int in_saved_avma ;
-EXTER unsigned long avma;
+EXTER unsigned plong avma;
 EXTER GEN1 gzero;
 EXTER GEN1 icopy_x;
+/* #define DEBUG_AVMA */
+
+#ifdef DEBUG_AVMA
+#define save_avma long lvma = (in_saved_avma = 1, avma)
+#define restore_avma avma = (in_saved_avma = 0, lvma)
+#else
 #define save_avma long lvma = avma
 #define restore_avma avma = lvma
+#endif
+
+#endif /* NO GMP */
+#endif _MP_H
 
   /* copy x to y, increasing space by factor of 2  */
 object make_integer();
