@@ -11,7 +11,7 @@
 /*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/
 /*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/
 
-extern unsigned long overflow,hiremainder;
+extern unsigned plong overflow,hiremainder;
 
 /* mp.c */
 
@@ -22,19 +22,19 @@ extern unsigned long overflow,hiremainder;
 #define setlgef(x,s)      (((GEN)(x))[1]=(((GEN)(x))[1]&0xffff0000)+s)
 #define signe(x)          (((GEN)(x))[1]>>24)
 #endif
-#define setsigne(x,s)     (((GEN)(x))[1]=(((GEN)(x))[1]&0xffffff)+(s<<24))
-#define typ(x)            (((unsigned long)((GEN)(x))[0])>>24)
-#define settyp(x,s)       (((GEN)(x))[0]=(((GEN)(x))[0]&0xffffff)+(s<<24))
-#define pere(x)           ((unsigned long)(((GEN)(x))[0]&0xffffff)>>16)
-#define setpere(x,s)      (((GEN)(x))[0]=(((GEN)(x))[0]&0xff00ffff)+(s<<16))
+#define setsigne(x,s)     (((GEN)(x))[1]=(((GEN)(x))[1]&0xffffff)+((s)<<24))
+#define typ(x)            (((unsigned plong)((GEN)(x))[0])>>24)
+#define settyp(x,s)       (((GEN)(x))[0]=(((GEN)(x))[0]&0xffffff)+((s)<<24))
+#define pere(x)           ((unsigned plong)(((GEN)(x))[0]&0xffffff)>>16)
+#define setpere(x,s)      (((GEN)(x))[0]=(((GEN)(x))[0]&0xff00ffff)+((s)<<16))
 #define expo(x)           ((((GEN)(x))[1]&0xffffff)-0x800000)
 #define setexpo(x,s)      (((GEN)(x))[1]=(((GEN)(x))[1]&0xff000000)+(0x800000+s))
 #define valp(x)           ((((GEN)(x))[1]&0xffff)-0x8000)
 #define setvalp(x,s)      (((GEN)(x))[1]=(((GEN)(x))[1]&0xffff0000)+(0x8000+s))
-#define precp(x)          (((unsigned long)((GEN)(x))[1])>>16)
-#define setprecp(x,s)     (((GEN)(x))[1]=(((GEN)(x))[1]&0xffff)+(s<<16))
+#define precp(x)          (((unsigned plong)((GEN)(x))[1])>>16)
+#define setprecp(x,s)     (((GEN)(x))[1]=(((GEN)(x))[1]&0xffff)+((s)<<16))
 #define varn(x)           ((((GEN)(x))[1]&0xff0000)>>16)
-#define setvarn(x,s)      (((GEN)(x))[1]=(((GEN)(x))[1]&0xff00ffff)+(s<<16))
+#define setvarn(x,s)      (((GEN)(x))[1]=(((GEN)(x))[1]&0xff00ffff)+((s)<<16))
 #define mant(x,i)         ((((GEN)(x))[1]&0xff000000)?((GEN)(x))[i+1]:0)
 #define setmant(x,i,s)    (((GEN)(x))[i+1]=s)
 #define affrs(x,s)        (err(affer4))
@@ -110,7 +110,7 @@ GEN     divsi(),divis(),divsr(),divrs(),divir();
 GEN     divri(),divrr(),mpdiv(),convi(),confrac();
 GEN     modss(),resss(),modsi(),ressi(),modis(),resis(),modii();
 GEN     dvmdii(),dvmdsi(),dvmdis();
-long    itos(),vals(),vali(),divisii();
+plong     itos(),vals(),vali(),divisii();
 int     expi();
 void    affii(),affir(),affrr(),mulsii(),addsii(),divsiz(),divisz(),divssz();
 void    dvmdssz(),dvmdsiz(),dvmdisz(),dvmdiiz(),mpdivz(),modiiz();
