@@ -22,12 +22,6 @@
 #undef SFASL
 #define UNIXFASL "faslhp800.c"
 
-  /* since we do brk of the whole thing we use a smaller number */
-
-/*
-#undef MAXPAGE
-#define MAXPAGE 10000
-*/
 
 #define ADDITIONAL_FEATURES \
 		     ADD_FEATURE("HP9000-800"); \
@@ -81,7 +75,7 @@
 
 #undef LD_COMMAND
 
-#define LD_COMMAND(command,main,start,input,ldarg,output) \
+#define OBSOLETE_LD_COMMAND(command,main,start,input,ldarg,output) \
    { char buf[50];  int i; \
      char *b = &buf[sizeof(buf)]; \
      char *pp=input; \
@@ -96,6 +90,23 @@
        b, \
        main,start,start + data_off, input,ldarg,output);}
 
+
+#define LD_COMMAND(command,main,start,input,ldarg,output) \
+{ char buf[50];  int i; \
+     char *b = &buf[sizeof(buf)]; \
+     char *pp=input; \
+     *--b = 0; \
+     for(i=strlen(pp)-3; i >= 0 ; i--) \
+       if (pp[i]!='/') { *(--b) = pp[i];} \
+          else break; \
+  sprintf(command,\
+     " if nm %s | fgrep init_code > /dev/null ; then ld -d -a archive -s -e init_code -A %s -R %x -D0x%x %s %s -o %s /lib/dyncall.o 2>/dev/null ; exit 0  ; fi; \
+       if nm %s | fgrep init_%s > /dev/null ; then ld -d -a archive -s -e init_%s -A %s -R %x -D0x%x %s %s -o %s /lib/dyncall.o 2> /dev/null ; exit 0 ;fi ;  exit 1 ; ", \
+	  input, \
+       main,start,start + data_off, input,ldarg,output, \
+       input,b,b, \
+       main,start,start + data_off, input,ldarg,output);}
+
 /*  This is ok but does not do the init_filename case 
 #define LD_COMMAND(command,main,start,input,ldarg,output) \
   sprintf(command,\
@@ -134,6 +145,12 @@
 	       val = (val + 3) & ~3;
 
 
+/* the following 2 cause duplicate defs so we redefine them.. */
+
+#define calloc xxcalloc
+#define cfree xxcfree
+
+
 
 /* Begin for cmpinclude */
 
@@ -146,8 +163,8 @@
 #define _file __fileL
 #define _cnt __cnt
 
-#define DBEGIN 0x40000000   
-/* #define DBEGIN 0x800000 */
+/* #define DBEGIN 0x40000000   */
+
 
 #define NULL_OR_ON_C_STACK(x) (x == 0 ||   ((unsigned int) x) >=0x70000000)
 
