@@ -172,6 +172,7 @@ EXTER object  sKinternal ;
 EXTER object  sKnicknames ; 
 EXTER object  sKuse ; 
 EXTER object  sLApackageA ; 
+EXTER  object   fSset_gmp_allocate_relocatable (); 
 EXTER  object   fSallocate_bigger_fixnum_range (); 
 EXTER  object   fScmod  (); 
 EXTER  object   fScplus  (); 
@@ -314,6 +315,7 @@ EXTER object  sSpretty_print_format ;
 EXTER object  sSAprint_nansA ; 
 EXTER  object   fLformat  (); 
 EXTER object  sSAindent_formatted_outputA ; 
+EXTER  object   fSsetenv (); 
 EXTER  object   fLdelete_file  (); 
 EXTER  object   fLerror  (); 
 EXTER  object   fLcerror  (); 
