@@ -26,7 +26,7 @@ static L1()
 	object V4;
 	base[5]= base[4];
 	vs_top=(vs_base=base+5)+1;
-	(void) (*Lnk38)();
+	(void) (*Lnk39)();
 	if(vs_base>=vs_top){vs_top=sup;goto T3;}
 	V3= vs_base[0];
 	vs_base++;
@@ -65,22 +65,22 @@ static L2()
 	if(endp(V11))invalid_macro_call();
 	base[3]= (V11->c.c_car);
 	V11=V11->c.c_cdr;
-	{object V12=getf(V11,VV[39],OBJNULL);
+	{object V12=getf(V11,VV[40],OBJNULL);
 	if(V12==OBJNULL){
 	base[4]= Cnil;
 	} else {
 	base[4]= V12;}}
-	{object V13=getf(V11,VV[40],OBJNULL);
+	{object V13=getf(V11,VV[41],OBJNULL);
 	if(V13==OBJNULL){
 	base[5]= Cnil;
 	} else {
 	base[5]= V13;}}
-	{object V14=getf(V11,VV[41],OBJNULL);
+	{object V14=getf(V11,VV[42],OBJNULL);
 	if(V14==OBJNULL){
 	base[6]= Cnil;
 	} else {
 	base[6]= V14;}}
-	check_other_key(V11,3,VV[39],VV[40],VV[41]);}
+	check_other_key(V11,3,VV[40],VV[41],VV[42]);}
 	V10=V10->c.c_cdr;
 	base[7]= V10;}
 	if((base[4])==Cnil){
@@ -89,7 +89,7 @@ static L2()
 	object V16;
 	base[8]= base[7];
 	vs_top=(vs_base=base+8)+1;
-	(void) (*Lnk38)();
+	(void) (*Lnk39)();
 	if(vs_base>=vs_top){vs_top=sup;goto T14;}
 	V15= vs_base[0];
 	vs_base++;
@@ -166,7 +166,7 @@ static L4()
 	object V34;
 	object V35;
 	if(vs_top-vs_base<1) too_few_arguments();
-	parse_key(vs_base+3,FALSE,FALSE,3,VV[40],VV[41],VV[42]);
+	parse_key(vs_base+3,FALSE,FALSE,3,VV[41],VV[42],VV[43]);
 	V30=(base[0]);
 	vs_base += 1;
 	if(vs_base>=vs_top){vs_top=sup;goto T21;}
@@ -203,7 +203,7 @@ T23:;
 	base[11]= (V31);
 	base[12]= (V32);
 	vs_top=(vs_base=base+10)+3;
-	(void) (*Lnk43)();
+	(void) (*Lnk44)();
 	vs_top=sup;
 	base[9]= vs_base[0];
 	base[11]= (V36);
@@ -218,7 +218,7 @@ T33:;
 	base[11]= (V31);
 	base[12]= (V32);
 	vs_top=(vs_base=base+10)+3;
-	(void) (*Lnk44)();
+	Lread();
 	vs_top=sup;
 	base[9]= vs_base[0];
 	base[11]= (V36);
@@ -268,17 +268,16 @@ static L5()
 	(void) (*Lnk55)();
 	vs_top=sup;
 	V49= vs_base[0];
-	base[23]=symbol_function(VV[56]);
-	base[24]= (V37);
-	base[25]= VV[10];
-	base[26]= (V49);
+	base[23]= (V37);
+	base[24]= VV[10];
+	base[25]= (V49);
 	{object V50;
 	V50= (V38);
-	 vs_top=base+27;
+	 vs_top=base+26;
 	 while(!endp(V50))
 	 {vs_push(car(V50));V50=cdr(V50);}
-	vs_base=base+24;}
-	(void) (*Lnk56)();
+	vs_base=base+23;}
+	Lwrite();
 	vs_top=sup;
 	base[23]= (V49);
 	vs_top=(vs_base=base+23)+1;
@@ -353,7 +352,7 @@ static L8()
 	object V58;
 	base[5]= base[4];
 	vs_top=(vs_base=base+5)+1;
-	(void) (*Lnk38)();
+	(void) (*Lnk39)();
 	if(vs_base>=vs_top){vs_top=sup;goto T62;}
 	V57= vs_base[0];
 	vs_base++;
@@ -369,7 +368,7 @@ T64:;
 	V59= list(2,base[2],make_cons(VV[11],base[3]));
 	V60= make_cons(/* INLINE-ARGS */V59,Cnil);
 	V61= make_cons(VV[2],(V58));
-	V62= list(3,VV[1],/* INLINE-ARGS */V61,list(2,VV[3],base[2]));
+	V62= list(3,VV[1],/* INLINE-ARGS */V61,list(3,VV[12],base[2],list(2,VV[3],base[2])));
 	V63= make_cons(/* INLINE-ARGS */V62,Cnil);
 	base[5]= listA(3,VV[0],/* INLINE-ARGS */V60,append((V57),/* INLINE-ARGS */V63));
 	vs_top=(vs_base=base+5)+1;
@@ -400,23 +399,23 @@ T66:;
 T69:;
 	if(((V64))==Cnil){
 	goto T72;}
-	base[0]= symbol_value(VV[12]);
-	base[1]= VV[13];
+	base[0]= symbol_value(VV[13]);
+	base[1]= VV[14];
 	base[2]= (V64);
 	base[3]= (V65);
 	vs_top=(vs_base=base+0)+4;
-	(void) (*Lnk57)();
+	Lformat();
 	vs_top=sup;
 T72:;
-	base[0]= symbol_value(VV[12]);
+	base[0]= symbol_value(VV[13]);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk44)();
+	Lread();
 	vs_top=sup;
 	V67= vs_base[0];
 	base[0]= symbol_name((V67));
-	base[1]= VV[14];
+	base[1]= VV[15];
 	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk58)();
+	Lstring_equal();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T84;}
@@ -424,9 +423,9 @@ T72:;
 	VMR9(V68)}
 T84:;
 	base[0]= symbol_name((V67));
-	base[1]= VV[15];
+	base[1]= VV[16];
 	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk58)();
+	Lstring_equal();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T82;}
@@ -460,23 +459,23 @@ T95:;
 T98:;
 	if(((V70))==Cnil){
 	goto T101;}
-	base[0]= symbol_value(VV[12]);
-	base[1]= VV[16];
+	base[0]= symbol_value(VV[13]);
+	base[1]= VV[17];
 	base[2]= (V70);
 	base[3]= (V71);
 	vs_top=(vs_base=base+0)+4;
-	(void) (*Lnk57)();
+	Lformat();
 	vs_top=sup;
 T101:;
-	base[0]= symbol_value(VV[12]);
+	base[0]= symbol_value(VV[13]);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk44)();
+	Lread();
 	vs_top=sup;
 	V73= vs_base[0];
 	base[0]= symbol_name((V73));
-	base[1]= VV[17];
+	base[1]= VV[18];
 	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk58)();
+	Lstring_equal();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T113;}
@@ -484,9 +483,9 @@ T101:;
 	VMR10(V74)}
 T113:;
 	base[0]= symbol_name((V73));
-	base[1]= VV[18];
+	base[1]= VV[19];
 	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk58)();
+	Lstring_equal();
 	vs_top=sup;
 	if((vs_base[0])==Cnil){
 	goto T111;}
@@ -508,10 +507,10 @@ TTL:;
 	base[2]= Cnil;
 	base[3]= Ct;
 	vs_top=(vs_base=base+0)+4;
-	(void) (*Lnk44)();
+	Lread();
 	vs_top=sup;
 	V82= vs_base[0];
-	if((symbol_value(VV[19]))==Cnil){
+	if((symbol_value(VV[20]))==Cnil){
 	goto T129;}
 	{object V83 = Cnil;
 	VMR11(V83)}
@@ -526,7 +525,7 @@ T132:;
 	if(!(number_compare((V84),(V81))>=0)){
 	goto T133;}
 	V87= nreverse((V85));
-	{object V88 = (VFUN_NARGS=3,(*(LnkLI59))(/* INLINE-ARGS */V87,VV[20],(V82)));
+	{object V88 = (VFUN_NARGS=3,(*(LnkLI56))(/* INLINE-ARGS */V87,VV[21],(V82)));
 	VMR11(V88)}
 T133:;
 	V84= one_plus((V84));
@@ -561,47 +560,47 @@ static object LI12(va_alist)
 	V92= va_arg(ap,object);}
 	--narg; goto T147;
 T145:;
-	V90= VV[21];
+	V90= VV[22];
 	V91= Cnil;
 T146:;
-	V92= VV[22];
+	V92= VV[23];
 T147:;
 	if(((V91))!=Cnil){
 	goto T151;}
-	if((symbol_value(VV[23]))!=Cnil){
+	if((symbol_value(VV[24]))!=Cnil){
 	goto T153;}
-	base[0]= VV[24];
+	base[0]= VV[25];
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk60)();
+	Lerror();
 	vs_top=sup;
 T153:;
-	if(!((symbol_value(VV[25]))==(symbol_value(VV[26])))){
+	if(!((symbol_value(VV[26]))==(symbol_value(VV[27])))){
 	goto T159;}
-	setq(VV[26],symbol_value(VV[27]));
+	setq(VV[27],symbol_value(VV[28]));
 	goto T157;
 T159:;
-	(void)((VFUN_NARGS=1,(*(LnkLI61))(VV[28])));
+	(void)((VFUN_NARGS=1,(*(LnkLI57))(VV[29])));
 T157:;
-	base[0]= symbol_value(VV[23]);
+	base[0]= symbol_value(VV[24]);
 	vs_top=(vs_base=base+0)+1;
-	(void) (*Lnk3)();
+	Lclose();
 	vs_top=sup;
-	setq(VV[23],Cnil);
+	setq(VV[24],Cnil);
 	base[0]= Ct;
-	base[1]= VV[29];
-	base[2]= symbol_value(VV[30]);
+	base[1]= VV[30];
+	base[2]= symbol_value(VV[31]);
 	vs_top=(vs_base=base+0)+3;
-	(void) (*Lnk57)();
+	Lformat();
 	vs_top=sup;
 	{object V93 = vs_base[0];
 	VMR12(V93)}
 T151:;
-	if((symbol_value(VV[23]))==Cnil){
+	if((symbol_value(VV[24]))==Cnil){
 	goto T170;}
-	base[0]= VV[31];
-	base[1]= symbol_value(VV[30]);
+	base[0]= VV[32];
+	base[1]= symbol_value(VV[31]);
 	vs_top=(vs_base=base+0)+2;
-	(void) (*Lnk60)();
+	Lerror();
 	vs_top=sup;
 	{object V94 = vs_base[0];
 	VMR12(V94)}
@@ -610,40 +609,40 @@ T170:;
 	object V96;
 	base[2]= (V90);
 	vs_top=(vs_base=base+2)+1;
-	(void) (*Lnk62)();
+	Lnamestring();
 	vs_top=sup;
 	V95= vs_base[0];
 	base[2]= (V90);
-	base[3]= VV[32];
-	base[4]= VV[33];
-	base[5]= VV[34];
+	base[3]= VV[33];
+	base[4]= VV[34];
+	base[5]= VV[35];
 	base[6]= (V92);
-	base[7]= VV[35];
-	base[8]= VV[36];
+	base[7]= VV[36];
+	base[8]= VV[37];
 	vs_top=(vs_base=base+2)+7;
 	(void) (*Lnk11)();
 	vs_top=sup;
 	V96= vs_base[0];
-	setq(VV[30],(V95));
-	setq(VV[23],(V96));
-	setq(VV[27],symbol_value(VV[26]));
-	base[3]= symbol_value(VV[26]);
+	setq(VV[31],(V95));
+	setq(VV[24],(V96));
+	setq(VV[28],symbol_value(VV[27]));
+	base[3]= symbol_value(VV[27]);
 	base[4]= (V96);
 	vs_top=(vs_base=base+3)+2;
-	(void) (*Lnk63)();
+	Lmake_echo_stream();
 	vs_top=sup;
 	base[2]= vs_base[0];
-	base[4]= symbol_value(VV[26]);
+	base[4]= symbol_value(VV[27]);
 	base[5]= (V96);
 	vs_top=(vs_base=base+4)+2;
-	(void) (*Lnk64)();
+	Lmake_broadcast_stream();
 	vs_top=sup;
 	base[3]= vs_base[0];
 	vs_top=(vs_base=base+2)+2;
-	(void) (*Lnk65)();
+	Lmake_two_way_stream();
 	vs_top=sup;
-	setq(VV[25],vs_base[0]);
-	setq(VV[26],symbol_value(VV[25]));
+	setq(VV[26],vs_base[0]);
+	setq(VV[27],symbol_value(VV[26]));
 	{object V97;
 	object V98;
 	object V99;
@@ -651,7 +650,7 @@ T170:;
 	object V101;
 	object V102;
 	vs_base=vs_top;
-	(void) (*Lnk66)();
+	(void) (*Lnk58)();
 	if(vs_base>=vs_top){vs_top=sup;goto T201;}
 	V97= vs_base[0];
 	vs_base++;
@@ -685,7 +684,7 @@ T206:;
 	V102= Cnil;
 T207:;
 	base[2]= Ct;
-	base[3]= VV[37];
+	base[3]= VV[38];
 	base[4]= (V95);
 	base[5]= (V102);
 	base[6]= (V101);
@@ -694,28 +693,23 @@ T207:;
 	base[9]= (V98);
 	base[10]= (V97);
 	vs_top=(vs_base=base+2)+9;
-	(void) (*Lnk57)();
+	Lformat();
 	vs_top=sup;
 	{object V103 = vs_base[0];
 	VMR12(V103)}}}}
 	}
-static LnkT66(){ call_or_link(VV[66],&Lnk66);} /* GET-DECODED-TIME */
-static LnkT65(){ call_or_link(VV[65],&Lnk65);} /* MAKE-TWO-WAY-STREAM */
-static LnkT64(){ call_or_link(VV[64],&Lnk64);} /* MAKE-BROADCAST-STREAM */
-static LnkT63(){ call_or_link(VV[63],&Lnk63);} /* MAKE-ECHO-STREAM */
+static LnkT58(){ call_or_link(VV[58],&Lnk58);} /* GET-DECODED-TIME */
 static LnkT11(){ call_or_link(VV[11],&Lnk11);} /* OPEN */
-static LnkT62(){ call_or_link(VV[62],&Lnk62);} /* NAMESTRING */
-static LnkT3(){ call_or_link(VV[3],&Lnk3);} /* CLOSE */
-static object  LnkTLI61(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[61],&LnkLI61,ap);} /* WARN */
-static LnkT60(){ call_or_link(VV[60],&Lnk60);} /* ERROR */
-static object  LnkTLI59(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[59],&LnkLI59,ap);} /* MAKE-ARRAY */
-static LnkT58(){ call_or_link(VV[58],&Lnk58);} /* STRING-EQUAL */
-static LnkT57(){ call_or_link(VV[57],&Lnk57);} /* FORMAT */
+static object  LnkTLI57(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[57],&LnkLI57,ap);} /* WARN */
+static object  LnkTLI56(va_alist)va_dcl{va_list ap;va_start(ap);return(object )call_vproc(VV[56],&LnkLI56,ap);} /* MAKE-ARRAY */
 static LnkT9(){ call_or_link(VV[9],&Lnk9);} /* GET-OUTPUT-STREAM-STRING */
-static LnkT56(){ call_or_link(VV[56],&Lnk56);} /* WRITE */
 static LnkT55(){ call_or_link(VV[55],&Lnk55);} /* MAKE-STRING-OUTPUT-STREAM */
-static LnkT44(){ call_or_link(VV[44],&Lnk44);} /* READ */
 static LnkT6(){ call_or_link(VV[6],&Lnk6);} /* GET-STRING-INPUT-STREAM-INDEX */
-static LnkT43(){ call_or_link(VV[43],&Lnk43);} /* READ-PRESERVING-WHITESPACE */
+static LnkT44(){ call_or_link(VV[44],&Lnk44);} /* READ-PRESERVING-WHITESPACE */
 static LnkT4(){ call_or_link(VV[4],&Lnk4);} /* MAKE-STRING-INPUT-STREAM */
-static LnkT38(){ call_or_link(VV[38],&Lnk38);} /* FIND-DECLARATIONS */
+static LnkT39(){ call_or_link(VV[39],&Lnk39);} /* FIND-DECLARATIONS */
+
+#ifdef SYSTEM_SPECIAL_INIT
+SYSTEM_SPECIAL_INIT
+#endif
+
