@@ -1161,12 +1161,15 @@ static float sf1,sf2;
 static sf_eql()
 {return(sf1==sf2);}
 
-static lf_eql(a,b)
-     double a,b;
-{return(a==b);}
-#define LF_EQL(a,b) lf_eql((double)(a),(double)(b))
+
+
+int lf_eqlp();
+#define LF_EQL(a,b) (lf1=a,lf2=b,lf_eqlp(&lf1,&lf2))
 #define SF_EQL(a,b) (sf1=a,sf2=b,sf_eql())
 
+void  _assure_in_memory ();
+
+#define FMEM(f) _assure_in_memory(&f)
 init_num_co()
 {
 	int l[2];
@@ -1174,6 +1177,7 @@ init_num_co()
 	double smallest_double, biggest_double;
 	float float_epsilon, float_negative_epsilon;
 	double double_epsilon, double_negative_epsilon;
+	double lf1,lf2;
 
 
 
@@ -1321,30 +1325,34 @@ init_num_co()
    too much precision, while the usual lisp eql,is not
    in line.
    We use SMALL as a multiple to come back up by.
+   We use FMEM(double_negative_epsilon)
+   to force the quantity into memory by taking its address
+   and then passing it to a function.
 */
 
 #define SMALL 1.05	
 	for (float_epsilon = 1.0;
-	     !SF_EQL((float)(1.0 + float_epsilon),(float)1.0);
+	     FMEM(float_epsilon),!SF_EQL((float)(1.0 + float_epsilon),(float)1.0);
 	     float_epsilon /= 2.0)
 		;
 	while(SF_EQL((float)(1.0 + float_epsilon),(float)1.0))
-	  float_epsilon=float_epsilon*SMALL;
+	  { FMEM(float_epsilon); float_epsilon=float_epsilon*SMALL;}
 	for (float_negative_epsilon = 1.0;
-	     !SF_EQL((float)(1.0 - float_negative_epsilon) ,(float)1.0);
+	    FMEM(float_negative_epsilon), !SF_EQL((float)(1.0 - float_negative_epsilon) ,(float)1.0);
 	     float_negative_epsilon /= 2.0)
 		;
 	while(SF_EQL((float)(1.0 - float_negative_epsilon) ,(float)1.0))
 	  float_negative_epsilon=float_negative_epsilon*SMALL;
 	for (double_epsilon = 1.0;
-	     !(LF_EQL(1.0 + double_epsilon, 1.0));
+	     FMEM(double_epsilon), !(LF_EQL(1.0 + double_epsilon, 1.0));
 	     double_epsilon /= 2.0)
 		;
 	while((LF_EQL(1.0 + double_epsilon, 1.0)))
 	  double_epsilon=double_epsilon*SMALL;
 	  ;
 	for (double_negative_epsilon = 1.0;
-	     !LF_EQL(1.0 - double_negative_epsilon , 1.0);
+	   FMEM(double_negative_epsilon),
+	       !LF_EQL(1.0 - double_negative_epsilon , 1.0);
 	     double_negative_epsilon /= 2.0)
 		;
 	while(LF_EQL(1.0 - double_negative_epsilon , 1.0))
