@@ -19,10 +19,13 @@ Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
 */
 
+
 #define IN_SOCKETS
 
 #include "include.h"
 
+#ifdef HAVE_NSOCKET
+
 #include "sheader.h"
 
 #include <sys/types.h>
@@ -79,9 +82,10 @@ sockaddr_in addr;
 
   if (port == 0)
     {
+#define MY_HTONS(x) htons((unsigned short)((x) & 0xffff))      
       int cRetry = 0;
       do {
-	addr.sin_port = iLastAddressUsed;
+	addr.sin_port = MY_HTONS(iLastAddressUsed);
 	rc = bind(s, (struct sockaddr *)&addr, n);
 
 	cRetry++;
@@ -100,7 +104,7 @@ sockaddr_in addr;
     }
   else
     {
-      addr.sin_port = port;
+      addr.sin_port = MY_HTONS(port);
       rc = bind(s, (struct sockaddr *)&addr, n);
     }
   if (rc < 0)
@@ -117,7 +121,7 @@ sockaddr_in addr;
       return Cnil;
     }
 
-  return make_cons(make_fixnum(s), make_fixnum(addr.sin_port));
+  return make_cons(make_fixnum(s), make_fixnum(ntohs(addr.sin_port)));
 }
 
 DEFUN("CLOSE-FD",object,fSclose_fd,SI,1,1,NONE,OI,OO,OO,OO,
@@ -181,23 +185,6 @@ sock_hostname_to_hostid_list(host_name)
   return addr_list;
 }
 
-/* Copy STRING to  BUF which has N bytes available.
-   If there is not enough space, malloc some */
-char *
-lisp_copy_to_null_terminated(string,buf,n)
-     char *buf;
-     int n;
-     object string;
-{ if(type_of(string) != t_string
-      && type_of(string) != t_symbol)
-    FEerror("Need to give symbol or string",0);
-  if (string->st.st_fillp +1 > n)
-    { buf= (void *)malloc(string->st.st_fillp +1);
-    }
-  bcopy(string->st.st_self,buf,string->st.st_fillp);
-  buf[string->st.st_fillp] = 0;
-  return buf;
-}
     
       
 
@@ -505,6 +492,8 @@ DEFUN("CLEAR-CONNECTION-STATE",int,fSclear_connection_state,
  return n;
 }
 
+#endif
+
 void
 write_timeout_error(s)
      char *s;
@@ -517,3 +506,4 @@ connection_failure(s)
 {FEerror("Connect failure: ~s",1,make_simple_string(s));
 }
 
+
